# Запуск бенчмарков

## CLI

```bash
benchos run [OPTIONS] [FILE]
```

Более подробно про CLI можно почитать в [документации](CLI.md).

### Примеры использования

```bash
# Запуск по имени класса (файл МойКласс.os должен существовать в текущей директории)
benchos run МойКласс

# Запуск по имени файла в текущей директории
benchos run МойКласс.os

# Запуск по абсолютному пути
benchos run /path/to/МойКласс.os

# Запуск всех бенчмарков в директории
benchos run /path/to/benchmarks

# Запуск всех бенчмарков в директории, включая вложенные каталоги
benchos run -r /path/to/benchmarks

# Рекурсивный запуск с мониторингом памяти и экспортом в JSON
benchos run -r -m -e json ./benchmarks/
```

## API

### Базовый сценарий

```bsl
// Запуск по типу класса бенчмарков
Результат = Бенчмаркинг.Запустить(Тип("МойКласс"));

// Запуск через экземпляр класса бенчмарков
Результат = Бенчмаркинг.Запустить(Новый МойКласс);
```

### Запуск отдельных бенчмарков

```bsl
ДескрипторыБенчмарков = Новый КоллекцияДескрипторовБенчмарков(Тип("МойКласс"));

// Запуск конкретного бенчмарка
ДескрипторБенчмарка = ДескрипторыБенчмарков.НайтиПоИмени("МойБенчмарк");
Результат = Бенчмаркинг.Запустить(ДескрипторБенчмарка);

// Запуск отфильтрованного списка
ДескрипторыБенчмарков.Фильтровать("Элемент -> Элемент.Категория() = ""МояКатегория""");
Результат = Бенчмаркинг.Запустить(ДескрипторыБенчмарков);
```

### Запуск бенчмарков из каталога

```bsl
// Запуск из каталога
Результат = Бенчмаркинг.ЗапуститьИзКаталога("/path/to/benchmarks");

// Запуск из каталога, включая вложенные каталоги
Результат = Бенчмаркинг.ЗапуститьИзКаталога("/path/to/benchmarks", Истина);
```

### Передача конфигурации

```bsl
// Создание новой конфигурации
Конфигурация = Новый КонфигурацияБенчмарков();
Конфигурация.УстановитьКоличествоИтераций(10);
Результат = Бенчмаркинг.Запустить(Тип("МойКласс"), Конфигурация);

// Модификация существующей конфигурации
Конфигурация = Новый КонфигурацияБенчмарков(Тип("МойКласс"));
Конфигурация.УстановитьКоличествоИтераций(10);
Результат = Бенчмаркинг.Запустить(Тип("МойКласс"), Конфигурация);
```
